@@ -337,17 +337,3 @@ uni_anim_view_set_is_playing (UniAnimView * aview, gboolean playing)
     else if (playing && aview->anim)
         uni_anim_view_updator (aview);
 }
-
-/**
- * uni_anim_view_get_is_playing:
- * @aview: A #UniImageView.
- * @returns: %TRUE if an animation is playing, %FALSE otherwise.
- *
- * Returns whether the animation is playing or not. If there is no
- * current animation, this method will always returns %FALSE.
- **/
-gboolean
-uni_anim_view_get_is_playing (UniAnimView * aview)
-{
-    return aview->timer_id && aview->anim;
-}
