@@ -56,7 +56,9 @@ extern "C" {
         { "Exif.Photo.Flash", _("Flash"), NULL },
         { "Exif.Photo.MeteringMode", _("Metering mode"), Exiv2::meteringMode },
         { "Exif.Image.FocalLength", _("Focal length"), Exiv2::focalLength },
-        { "Exif.Image.Software", _("Software"), NULL }
+        { "Exif.Image.Software", _("Software"), NULL },
+        { "Exif.Image.ImageDescription", _("Image description"), NULL },
+        { "Exif.Photo.UserComment", _("User comment"), NULL }
     };
 
     IptcDataDictionary iptcDataDictionary[] = {
@@ -68,8 +70,6 @@ extern "C" {
 
 #endif /* __cplusplus */
 
-void    uni_exif_dictionary_map     (void (*callback)(const char*, const char*, void*), 
-                                     void *user_data);
 void    uni_read_exiv2_map          (const char *uri, 
                                      void (*callback)(const char*, const char*, void*), 
                                      void *user_data);
@@ -84,4 +84,4 @@ int     uni_write_exiv2_from_cache  (const char *uri);
 #endif /* __cplusplus */
 
 
-#endif /* __UNI_EXIV2__H_ */
\ No newline at end of file
+#endif /* __UNI_EXIV2__H_ */
