@@ -46,7 +46,7 @@ void    uni_pixbuf_scale_blend          (GdkPixbuf * src,
                                          gdouble zoom,
                                          GdkInterpType interp, int check_x, int check_y);
 
-void    uni_draw_rect                   (GdkDrawable * drawable,
+void    uni_draw_rect                   (GdkWindow * window,
                                          GdkGC * gc, gboolean filled, GdkRectangle * rect);
 
 void    uni_rectangle_get_rects_around  (GdkRectangle * outer,
