@@ -44,21 +44,18 @@ static gboolean drawable_motion_cb (GtkWidget *widget,
 /***** Private actions ***************************************/
 /*************************************************************/
 static void
-vnr_crop_clear_rectangle(VnrCrop *crop)
+vnr_crop_draw_rectangle(VnrCrop *crop)
 {
     if(crop->do_redraw)
-        gdk_draw_rectangle (GDK_DRAWABLE(gtk_widget_get_window(crop->image)), crop->gc, FALSE,
+        gdk_draw_rectangle (gtk_widget_get_window(crop->image), crop->gc, FALSE,
                             crop->sub_x, crop->sub_y,
                             crop->sub_width, crop->sub_height);
 }
 
-static void
-vnr_crop_draw_rectangle(VnrCrop *crop)
+static inline void
+vnr_crop_clear_rectangle(VnrCrop *crop)
 {
-    if(crop->do_redraw)
-        gdk_draw_rectangle (GDK_DRAWABLE(gtk_widget_get_window(crop->image)), crop->gc, FALSE,
-                            crop->sub_x, crop->sub_y,
-                            crop->sub_width, crop->sub_height);
+    vnr_crop_draw_rectangle (crop);
 }
 
 static void
@@ -118,11 +115,25 @@ vnr_crop_build_dialog (VnrCrop *crop)
     original = uni_image_view_get_pixbuf(UNI_IMAGE_VIEW(crop->vnr_win->view));
 
     gdouble width, height;
+    gint max_width, max_height;
 
     width = crop->vnr_win->current_image_width;
     height = crop->vnr_win->current_image_height;
 
-    vnr_tools_fit_to_size_double(&height, &width, 400,400);
+    {
+        GdkScreen *screen;
+        GdkRectangle monitor;
+        screen = gtk_window_get_screen (GTK_WINDOW (crop->vnr_win));
+        gdk_screen_get_monitor_geometry (screen,
+                                        gdk_screen_get_monitor_at_window (screen,
+                                        gtk_widget_get_window (GTK_WIDGET (crop->vnr_win))),
+                                        &monitor);
+
+        max_width = monitor.width * 0.9 - 100;
+        max_height = monitor.height * 0.9 - 200;
+    }
+
+    vnr_tools_fit_to_size_double(&width, &height, max_width, max_height);
     crop->width = width;
     crop->height = height;
     crop->zoom = ( width/crop->vnr_win->current_image_width
@@ -266,10 +277,10 @@ static gboolean
 drawable_expose_cb (GtkWidget *widget, GdkEventExpose *event, VnrCrop *crop)
 {
     GdkWindow *window = gtk_widget_get_window(widget);
-    gdk_draw_pixbuf (GDK_DRAWABLE(window), NULL, crop->preview_pixbuf,
+    gdk_draw_pixbuf (window, NULL, crop->preview_pixbuf,
                      0, 0, 0, 0, -1, -1, GDK_RGB_DITHER_NORMAL, 0, 0);
 
-    crop->gc = gdk_gc_new(GDK_DRAWABLE(window));
+    crop->gc = gdk_gc_new(window);
     gdk_gc_set_function (crop->gc, GDK_INVERT);
     gdk_gc_set_line_attributes (crop->gc,
                                 2,
