@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2015 Siyan Panayotov <contact@siyanpanayotov.com>
+ * Copyright © 2009-2018 Siyan Panayotov <contact@siyanpanayotov.com>
  *
  * This file is part of Viewnior.
  *
@@ -29,6 +29,15 @@
 
 G_DEFINE_TYPE (VnrPrefs, vnr_prefs, G_TYPE_OBJECT);
 
+/**
+ * VNR_PREF_LOAD_KEY:
+ * @PK: Name of the VnrPrefs member.
+ * @PT: Type of the VnrPrefs member, a suffix for g_key_file_get_.
+ * @KN: Name of the key in the key file.
+ * @DEF: Default value for the preference.
+ */
+#define VNR_PREF_LOAD_KEY(PK, PT, KN, DEF)  prefs-> PK = g_key_file_get_ ## PT (conf, "prefs", KN, &read_error); if(read_error != NULL) { prefs-> PK = DEF; g_clear_error(&read_error); }
+
 /*************************************************************/
 /***** Private signal handlers *******************************/
 /*************************************************************/
@@ -40,6 +49,14 @@ toggle_show_hidden_cb (GtkToggleButton *togglebutton, gpointer user_data)
     vnr_prefs_save(VNR_PREFS(user_data));
 }
 
+static void
+toggle_dark_background_cb (GtkToggleButton *togglebutton, gpointer user_data)
+{
+    VNR_PREFS(user_data)->dark_background = gtk_toggle_button_get_active(togglebutton);
+    vnr_prefs_save(VNR_PREFS(user_data));
+    vnr_window_apply_preferences(VNR_WINDOW(VNR_PREFS(user_data)->vnr_win));
+}
+
 static void
 toggle_fit_on_fullscreen_cb (GtkToggleButton *togglebutton, gpointer user_data)
 {
@@ -76,8 +93,6 @@ change_zoom_mode_cb (GtkComboBox *widget, gpointer user_data)
     vnr_prefs_save(VNR_PREFS(user_data));
 }
 
-#ifdef HAVE_WALLPAPER
-
 static void
 change_desktop_env_cb (GtkComboBox *widget, gpointer user_data)
 {
@@ -85,8 +100,6 @@ change_desktop_env_cb (GtkComboBox *widget, gpointer user_data)
     vnr_prefs_save(VNR_PREFS(user_data));
 }
 
-#endif /* HAVE_WALLPAPER */
-
 static void
 change_jpeg_quality_cb (GtkRange *range, gpointer user_data)
 {
@@ -137,7 +150,7 @@ change_spin_value_cb (GtkSpinButton *spinbutton, gpointer user_data)
 static gboolean
 key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
-    if(event->keyval == GDK_Escape)
+    if(event->keyval == GDK_KEY_Escape)
     {
         gtk_widget_hide(widget);
         return TRUE;
@@ -155,6 +168,7 @@ vnr_prefs_set_default(VnrPrefs *prefs)
 {
     prefs->zoom = VNR_PREFS_ZOOM_SMART;
     prefs->show_hidden = FALSE;
+    prefs->dark_background = FALSE;
     prefs->fit_on_fullscreen = TRUE;
     prefs->smooth_images = TRUE;
     prefs->confirm_delete = TRUE;
@@ -167,13 +181,13 @@ vnr_prefs_set_default(VnrPrefs *prefs)
     prefs->reload_on_save = FALSE;
     prefs->show_menu_bar = FALSE;
     prefs->show_toolbar = TRUE;
+    prefs->show_scrollbar = TRUE;
+    prefs->show_statusbar = FALSE;
     prefs->start_maximized = FALSE;
     prefs->start_slideshow = FALSE;
     prefs->start_fullscreen = FALSE;
     prefs->auto_resize = FALSE;
-#ifdef HAVE_WALLPAPER
-    prefs->desktop = VNR_PREFS_DESKTOP_GNOME3;
-#endif /* HAVE_WALLPAPER */
+    prefs->desktop = VNR_PREFS_DESKTOP_AUTO;
 }
 
 static GtkWidget *
@@ -185,24 +199,23 @@ build_dialog (VnrPrefs *prefs)
 
     GObject *close_button;
     GtkToggleButton *show_hidden;
+    GtkToggleButton *dark_background;
     GtkToggleButton *fit_on_fullscreen;
     GtkBox *zoom_mode_box;
-    GtkComboBox *zoom_mode;
+    GtkComboBoxText *zoom_mode;
     GtkToggleButton *smooth_images;
     GtkToggleButton *confirm_delete;
     GtkToggleButton *reload_on_save;
     GtkSpinButton *slideshow_timeout;
     GtkTable *behavior_table;
-    GtkComboBox *action_wheel;
-    GtkComboBox *action_click;
-    GtkComboBox *action_modify;
+    GtkComboBoxText *action_wheel;
+    GtkComboBoxText *action_click;
+    GtkComboBoxText *action_modify;
     GtkRange *jpeg_scale;
     GtkRange *png_scale;
 
-#ifdef HAVE_WALLPAPER
     GtkBox *desktop_box;
-    GtkComboBox *desktop_env;
-#endif /* HAVE_WALLPAPER */
+    GtkComboBoxText *desktop_env;
 
     builder = gtk_builder_new ();
     gtk_builder_add_from_file (builder, UI_PATH, &error);
@@ -226,6 +239,11 @@ build_dialog (VnrPrefs *prefs)
     gtk_toggle_button_set_active( show_hidden, prefs->show_hidden );
     g_signal_connect(G_OBJECT(show_hidden), "toggled", G_CALLBACK(toggle_show_hidden_cb), prefs);
 
+    /* Show dark background checkbox */
+    dark_background = GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "dark_background"));
+    gtk_toggle_button_set_active( dark_background, prefs->dark_background );
+    g_signal_connect(G_OBJECT(dark_background), "toggled", G_CALLBACK(toggle_dark_background_cb), prefs);
+
     /* Fit on fullscreen checkbox */
     fit_on_fullscreen = GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "fit_on_fullscreen"));
     gtk_toggle_button_set_active( fit_on_fullscreen, prefs->fit_on_fullscreen );
@@ -265,65 +283,67 @@ build_dialog (VnrPrefs *prefs)
     /* Zoom mode combo box */
     zoom_mode_box = GTK_BOX (gtk_builder_get_object (builder, "zoom_mode_box"));
 
-    zoom_mode = (GtkComboBox*) gtk_combo_box_new_text();
-    gtk_combo_box_append_text(zoom_mode, _("Smart Mode"));
-    gtk_combo_box_append_text(zoom_mode, _("1:1 Mode"));
-    gtk_combo_box_append_text(zoom_mode, _("Fit To Window Mode"));
-    gtk_combo_box_append_text(zoom_mode, _("Last Used Mode"));
-    gtk_combo_box_set_active(zoom_mode, prefs->zoom);
+    zoom_mode = (GtkComboBoxText*) gtk_combo_box_text_new();
+    gtk_combo_box_text_append_text(zoom_mode, _("Smart Mode"));
+    gtk_combo_box_text_append_text(zoom_mode, _("1:1 Mode"));
+    gtk_combo_box_text_append_text(zoom_mode, _("Fit To Window Mode"));
+    gtk_combo_box_text_append_text(zoom_mode, _("Last Used Mode"));
+    gtk_combo_box_set_active(GTK_COMBO_BOX(zoom_mode), prefs->zoom);
 
     gtk_box_pack_end (zoom_mode_box, GTK_WIDGET(zoom_mode), FALSE, FALSE, 0);
     gtk_widget_show(GTK_WIDGET(zoom_mode));
 
     g_signal_connect(G_OBJECT(zoom_mode), "changed", G_CALLBACK(change_zoom_mode_cb), prefs);
 
-#ifdef HAVE_WALLPAPER
     /* Desktop combo box */
     desktop_box = GTK_BOX (gtk_builder_get_object (builder, "desktop_box"));
 
-    desktop_env = (GtkComboBox*) gtk_combo_box_new_text();
-    gtk_combo_box_append_text(desktop_env, "GNOME 2");
-    gtk_combo_box_append_text(desktop_env, "GNOME 3");
-    gtk_combo_box_append_text(desktop_env, "XFCE");
-    gtk_combo_box_append_text(desktop_env, "LXDE");
-    gtk_combo_box_append_text(desktop_env, "FluxBox");
-    gtk_combo_box_append_text(desktop_env, "Nitrogen");
-    gtk_combo_box_set_active(desktop_env, prefs->desktop);
+    desktop_env = (GtkComboBoxText*) gtk_combo_box_text_new();
+    gtk_combo_box_text_append_text(desktop_env, "GNOME 2");
+    gtk_combo_box_text_append_text(desktop_env, "GNOME 3");
+    gtk_combo_box_text_append_text(desktop_env, "XFCE");
+    gtk_combo_box_text_append_text(desktop_env, "LXDE");
+    gtk_combo_box_text_append_text(desktop_env, "PUPPY");
+    gtk_combo_box_text_append_text(desktop_env, "FluxBox");
+    gtk_combo_box_text_append_text(desktop_env, "Nitrogen");
+    gtk_combo_box_text_append_text(desktop_env, "MATE");
+    gtk_combo_box_text_append_text(desktop_env, "Cinnamon");
+    gtk_combo_box_text_append_text(desktop_env, _("Autodetect"));
+    gtk_combo_box_set_active(GTK_COMBO_BOX(desktop_env), prefs->desktop);
 
     gtk_box_pack_end (desktop_box, GTK_WIDGET(desktop_env), FALSE, FALSE, 0);
     gtk_widget_show(GTK_WIDGET(desktop_env));
 
     g_signal_connect(G_OBJECT(desktop_env), "changed", G_CALLBACK(change_desktop_env_cb), prefs);
-#endif /* HAVE_WALLPAPER */
 
     /* Behavior combo boxes */
     behavior_table = GTK_TABLE (gtk_builder_get_object (builder, "behavior_table"));
 
-    action_wheel = (GtkComboBox*) gtk_combo_box_new_text();
-    gtk_combo_box_append_text(action_wheel, _("Navigate images"));
-    gtk_combo_box_append_text(action_wheel, _("Zoom image"));
-    gtk_combo_box_append_text(action_wheel, _("Scroll image up/down"));
-    gtk_combo_box_set_active(action_wheel, prefs->behavior_wheel);
+    action_wheel = (GtkComboBoxText*) gtk_combo_box_text_new();
+    gtk_combo_box_text_append_text(action_wheel, _("Navigate images"));
+    gtk_combo_box_text_append_text(action_wheel, _("Zoom image"));
+    gtk_combo_box_text_append_text(action_wheel, _("Scroll image up/down"));
+    gtk_combo_box_set_active(GTK_COMBO_BOX(action_wheel), prefs->behavior_wheel);
 
     gtk_table_attach (behavior_table, GTK_WIDGET(action_wheel), 1,2,0,1, GTK_FILL,0, 0,0);
     gtk_widget_show(GTK_WIDGET(action_wheel));
     g_signal_connect(G_OBJECT(action_wheel), "changed", G_CALLBACK(change_action_wheel_cb), prefs);
 
-    action_click = (GtkComboBox*) gtk_combo_box_new_text();
-    gtk_combo_box_append_text(action_click, _("Switch zoom modes"));
-    gtk_combo_box_append_text(action_click, _("Enter fullscreen mode"));
-    gtk_combo_box_append_text(action_click, _("Navigate images"));
-    gtk_combo_box_set_active(action_click, prefs->behavior_click);
+    action_click = (GtkComboBoxText*) gtk_combo_box_text_new();
+    gtk_combo_box_text_append_text(action_click, _("Switch zoom modes"));
+    gtk_combo_box_text_append_text(action_click, _("Enter fullscreen mode"));
+    gtk_combo_box_text_append_text(action_click, _("Navigate images"));
+    gtk_combo_box_set_active(GTK_COMBO_BOX(action_click), prefs->behavior_click);
 
     gtk_table_attach (behavior_table, GTK_WIDGET(action_click), 1,2,1,2, GTK_FILL,0, 0,0);
     gtk_widget_show(GTK_WIDGET(action_click));
     g_signal_connect(G_OBJECT(action_click), "changed", G_CALLBACK(change_action_click_cb), prefs);
 
-    action_modify = (GtkComboBox*) gtk_combo_box_new_text();
-    gtk_combo_box_append_text(action_modify, _("Ask every time"));
-    gtk_combo_box_append_text(action_modify, _("Autosave"));
-    gtk_combo_box_append_text(action_modify, _("Ignore changes"));
-    gtk_combo_box_set_active(action_modify, prefs->behavior_modify);
+    action_modify = (GtkComboBoxText*) gtk_combo_box_text_new();
+    gtk_combo_box_text_append_text(action_modify, _("Ask every time"));
+    gtk_combo_box_text_append_text(action_modify, _("Autosave"));
+    gtk_combo_box_text_append_text(action_modify, _("Ignore changes"));
+    gtk_combo_box_set_active(GTK_COMBO_BOX(action_modify), prefs->behavior_modify);
 
     gtk_table_attach (behavior_table, GTK_WIDGET(action_modify), 1,2,2,3, GTK_FILL,0, 0,0);
     gtk_widget_show(GTK_WIDGET(action_modify));
@@ -341,52 +361,45 @@ build_dialog (VnrPrefs *prefs)
 }
 
 static gboolean
-vnr_prefs_load (VnrPrefs *prefs)
+vnr_prefs_load (VnrPrefs *prefs, GError **error)
 {
-    GKeyFile *conf;
-    GError *error = NULL;
+    GKeyFile *conf = g_key_file_new();
+    GError *read_error = NULL;
+    GError *load_file_error = NULL;
     const gchar *path;
 
     path = g_build_filename (g_get_user_config_dir(), PACKAGE, "viewnior.conf", NULL);
-
-    conf = g_key_file_new();
-    g_key_file_load_from_file (conf, path, G_KEY_FILE_NONE, &error);
+    g_key_file_load_from_file (conf, path, G_KEY_FILE_NONE, &load_file_error);
 
     g_free((char*)path);
 
-    if(error != NULL)
+    if(load_file_error != NULL)
     {
-        g_warning("Loading config file: %s. All preferences are set to their default values. Saving ...", error->message);
+        g_propagate_error (error, load_file_error);
         g_key_file_free (conf);
         return FALSE;
     }
 
-    prefs->zoom = g_key_file_get_integer (conf, "prefs", "zoom-mode", &error);
-    prefs->fit_on_fullscreen = g_key_file_get_boolean (conf, "prefs", "fit-on-fullscreen", &error);
-    prefs->show_hidden = g_key_file_get_boolean (conf, "prefs", "show-hidden", &error);
-    prefs->smooth_images = g_key_file_get_boolean (conf, "prefs", "smooth-images", &error);
-    prefs->confirm_delete = g_key_file_get_boolean (conf, "prefs", "confirm-delete", &error);
-    prefs->reload_on_save = g_key_file_get_boolean (conf, "prefs", "reload-on-save", &error);
-    prefs->show_menu_bar = g_key_file_get_boolean (conf, "prefs", "show-menu-bar", &error);
-    prefs->show_toolbar = g_key_file_get_boolean (conf, "prefs", "show-toolbar", &error);
-    prefs->start_maximized = g_key_file_get_boolean (conf, "prefs", "start-maximized", &error);
-    prefs->slideshow_timeout = g_key_file_get_integer (conf, "prefs", "slideshow-timeout", &error);
-    prefs->auto_resize = g_key_file_get_boolean (conf, "prefs", "auto-resize", &error);
-    prefs->behavior_wheel = g_key_file_get_integer (conf, "prefs", "behavior-wheel", &error);
-    prefs->behavior_click = g_key_file_get_integer (conf, "prefs", "behavior-click", &error);
-    prefs->behavior_modify = g_key_file_get_integer (conf, "prefs", "behavior-modify", &error);
-    prefs->jpeg_quality = g_key_file_get_integer (conf, "prefs", "jpeg-quality", &error);
-    prefs->png_compression = g_key_file_get_integer (conf, "prefs", "png-compression", &error);
-#ifdef HAVE_WALLPAPER
-    prefs->desktop = g_key_file_get_integer (conf, "prefs", "desktop", &error);
-#endif /* HAVE_WALLPAPER */
-
-    if(error != NULL)
-    {
-        g_warning("Parsing config file: %s. All preferences are set to their default values.", error->message);
-        g_key_file_free (conf);
-        return FALSE;
-    }
+    VNR_PREF_LOAD_KEY (zoom, integer, "zoom-mode", VNR_PREFS_ZOOM_SMART);
+    VNR_PREF_LOAD_KEY (fit_on_fullscreen, boolean, "fit-on-fullscreen", TRUE);
+    VNR_PREF_LOAD_KEY (show_hidden, boolean, "show-hidden", FALSE);
+    VNR_PREF_LOAD_KEY (dark_background, boolean, "dark-background", FALSE);
+    VNR_PREF_LOAD_KEY (smooth_images, boolean, "smooth-images", TRUE);
+    VNR_PREF_LOAD_KEY (confirm_delete, boolean, "confirm-delete", TRUE);
+    VNR_PREF_LOAD_KEY (reload_on_save, boolean, "reload-on-save", FALSE);
+    VNR_PREF_LOAD_KEY (show_menu_bar, boolean, "show-menu-bar", FALSE);
+    VNR_PREF_LOAD_KEY (show_toolbar, boolean, "show-toolbar", TRUE);
+    VNR_PREF_LOAD_KEY (show_scrollbar, boolean, "show-scrollbar", TRUE);
+    VNR_PREF_LOAD_KEY (show_statusbar, boolean, "show-statusbar", FALSE);
+    VNR_PREF_LOAD_KEY (start_maximized, boolean, "start-maximized", FALSE);
+    VNR_PREF_LOAD_KEY (slideshow_timeout, integer, "slideshow-timeout", 5);
+    VNR_PREF_LOAD_KEY (auto_resize, boolean, "auto-resize", FALSE);
+    VNR_PREF_LOAD_KEY (behavior_wheel, integer, "behavior-wheel", VNR_PREFS_WHEEL_ZOOM);
+    VNR_PREF_LOAD_KEY (behavior_click, integer, "behavior-click", VNR_PREFS_CLICK_ZOOM);
+    VNR_PREF_LOAD_KEY (behavior_modify, integer, "behavior-modify", VNR_PREFS_MODIFY_ASK);
+    VNR_PREF_LOAD_KEY (jpeg_quality, integer, "jpeg-quality", 90);
+    VNR_PREF_LOAD_KEY (png_compression, integer, "png-compression", 9);
+    VNR_PREF_LOAD_KEY (desktop, integer, "desktop", VNR_PREFS_DESKTOP_AUTO);
 
     g_key_file_free (conf);
 
@@ -415,8 +428,11 @@ vnr_prefs_new (GtkWidget *vnr_win)
 static void
 vnr_prefs_init (VnrPrefs * prefs)
 {
-    if ( !vnr_prefs_load (prefs) )
+    GError *error = NULL;
+
+    if ( !vnr_prefs_load (prefs, &error) )
     {
+        g_warning("Error loading config file: %s. All preferences are set to their default values. Saving ...", error->message);
         vnr_prefs_set_default(prefs);
         vnr_prefs_save (prefs);
     }
@@ -455,11 +471,14 @@ vnr_prefs_save (VnrPrefs *prefs)
     g_key_file_set_integer (conf, "prefs", "zoom-mode", prefs->zoom);
     g_key_file_set_boolean (conf, "prefs", "fit-on-fullscreen", prefs->fit_on_fullscreen);
     g_key_file_set_boolean (conf, "prefs", "show-hidden", prefs->show_hidden);
+    g_key_file_set_boolean (conf, "prefs", "dark-background", prefs->dark_background);
     g_key_file_set_boolean (conf, "prefs", "smooth-images", prefs->smooth_images);
     g_key_file_set_boolean (conf, "prefs", "confirm-delete", prefs->confirm_delete);
     g_key_file_set_boolean (conf, "prefs", "reload-on-save", prefs->reload_on_save);
     g_key_file_set_boolean (conf, "prefs", "show-menu-bar", prefs->show_menu_bar);
     g_key_file_set_boolean (conf, "prefs", "show-toolbar", prefs->show_toolbar);
+    g_key_file_set_boolean (conf, "prefs", "show-scrollbar", prefs->show_scrollbar);
+    g_key_file_set_boolean (conf, "prefs", "show-statusbar", prefs->show_statusbar);
     g_key_file_set_boolean (conf, "prefs", "start-maximized", prefs->start_maximized);
     g_key_file_set_integer (conf, "prefs", "slideshow-timeout", prefs->slideshow_timeout);
     g_key_file_set_boolean (conf, "prefs", "auto-resize", prefs->auto_resize);
@@ -468,11 +487,7 @@ vnr_prefs_save (VnrPrefs *prefs)
     g_key_file_set_integer (conf, "prefs", "behavior-modify", prefs->behavior_modify);
     g_key_file_set_integer (conf, "prefs", "jpeg-quality", prefs->jpeg_quality);
     g_key_file_set_integer (conf, "prefs", "png-compression", prefs->png_compression);
-#ifdef HAVE_WALLPAPER
     g_key_file_set_integer (conf, "prefs", "desktop", prefs->desktop);
-#else
-    g_key_file_set_integer (conf, "prefs", "desktop", 0);
-#endif/* HAVE_WALLPAPER */
 
     if(g_mkdir_with_parents (dir, 0700) != 0)
         g_warning("Error creating config file's parent directory (%s)\n", dir);
@@ -481,8 +496,10 @@ vnr_prefs_save (VnrPrefs *prefs)
 
     if(rcfile != NULL)
     {
-        fputs(g_key_file_to_data (conf, NULL, NULL), rcfile);
+        gchar *data = g_key_file_to_data (conf, NULL, NULL);
+        fputs(data, rcfile);
         fclose(rcfile);
+        g_free(data);
     }
     else
         g_warning("Saving config file: Unable to open the configuration file for writing!\n");
@@ -511,6 +528,26 @@ vnr_prefs_set_show_toolbar (VnrPrefs *prefs, gboolean show_toolbar)
     }
 }
 
+void
+vnr_prefs_set_show_scrollbar (VnrPrefs *prefs, gboolean show_scrollbar)
+{
+    if(prefs->show_scrollbar != show_scrollbar)
+    {
+        prefs->show_scrollbar = show_scrollbar;
+        vnr_prefs_save(prefs);
+    }
+}
+
+void
+vnr_prefs_set_show_statusbar (VnrPrefs *prefs, gboolean show_statusbar)
+{
+    if(prefs->show_statusbar != show_statusbar)
+    {
+        prefs->show_statusbar = show_statusbar;
+        vnr_prefs_save(prefs);
+    }
+}
+
 void
 vnr_prefs_set_show_menu_bar (VnrPrefs *prefs, gboolean show_menu_bar)
 {
