@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2015 Siyan Panayotov <contact@siyanpanayotov.com>
+ * Copyright © 2009-2018 Siyan Panayotov <contact@siyanpanayotov.com>
  *
  * This file is part of Viewnior.
  *
@@ -46,47 +46,44 @@ typedef enum{
     VNR_PREFS_ZOOM_LAST_USED,
 } VnrPrefsZoom;
 
-
-#ifdef HAVE_WALLPAPER
-
 typedef enum{
     VNR_PREFS_DESKTOP_GNOME2,
     VNR_PREFS_DESKTOP_GNOME3,
     VNR_PREFS_DESKTOP_XFCE,
     VNR_PREFS_DESKTOP_LXDE,
+    VNR_PREFS_DESKTOP_PUPPY,
     VNR_PREFS_DESKTOP_FLUXBOX,
     VNR_PREFS_DESKTOP_NITROGEN,
+    VNR_PREFS_DESKTOP_MATE,
+    VNR_PREFS_DESKTOP_CINNAMON,
+    VNR_PREFS_DESKTOP_AUTO,
 } VnrPrefsDesktop;
 
-#endif /* HAVE_WALLPAPER */
-
 typedef enum{
     VNR_PREFS_WHEEL_NAVIGATE ,
     VNR_PREFS_WHEEL_ZOOM ,
     VNR_PREFS_WHEEL_SCROLL,
-} VnrPrefsWheel ;
+} VnrPrefsWheel;
 
 typedef enum{
     VNR_PREFS_CLICK_ZOOM ,
     VNR_PREFS_CLICK_FULLSCREEN ,
     VNR_PREFS_CLICK_NEXT ,
-} VnrPrefsClick ;
+} VnrPrefsClick;
 
 typedef enum{
     VNR_PREFS_MODIFY_ASK ,
     VNR_PREFS_MODIFY_SAVE ,
     VNR_PREFS_MODIFY_IGNORE ,
-} VnrPrefsModify ;
+} VnrPrefsModify;
 
 struct _VnrPrefs {
     GObject parent;
 
     VnrPrefsZoom zoom;
 
-#ifdef HAVE_WALLPAPER
     VnrPrefsDesktop desktop;
-#endif /* HAVE_WALLPAPER */
-    
+
     VnrPrefsWheel behavior_wheel;
     VnrPrefsClick behavior_click;
     VnrPrefsModify behavior_modify;
@@ -97,10 +94,13 @@ struct _VnrPrefs {
     gboolean reload_on_save;
     gboolean show_menu_bar;
     gboolean show_toolbar;
+    gboolean show_scrollbar;
+    gboolean show_statusbar;
     gboolean start_maximized;
     gboolean start_slideshow;
     gboolean start_fullscreen;
     gboolean auto_resize;
+    gboolean dark_background;
     int slideshow_timeout;
     int jpeg_quality;
     int png_compression;
@@ -119,9 +119,11 @@ GType     vnr_prefs_get_type (void) G_GNUC_CONST;
 
 GObject*  vnr_prefs_new (GtkWidget *window);
 void      vnr_prefs_show_dialog (VnrPrefs *prefs);
-void      vnr_prefs_set_slideshow_timeout   (VnrPrefs *prefs, int value);
-void      vnr_prefs_set_show_toolbar    (VnrPrefs *prefs, gboolean show_toolbar);
-void      vnr_prefs_set_show_menu_bar   (VnrPrefs *prefs, gboolean show_menu_bar);
+void      vnr_prefs_set_slideshow_timeout (VnrPrefs *prefs, int value);
+void      vnr_prefs_set_show_menu_bar     (VnrPrefs *prefs, gboolean show_menu_bar);
+void      vnr_prefs_set_show_toolbar      (VnrPrefs *prefs, gboolean show_toolbar);
+void      vnr_prefs_set_show_scrollbar    (VnrPrefs *prefs, gboolean show_scollbar);
+void      vnr_prefs_set_show_statusbar    (VnrPrefs *prefs, gboolean show_statusbar);
 gboolean  vnr_prefs_save (VnrPrefs *prefs);
 
 G_END_DECLS
