@@ -17,9 +17,6 @@
  * along with Viewnior.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __VNR_IMAGE_H__
-#define __VNR_IMAGE_H__
-
 #include <glib.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
@@ -131,12 +128,11 @@ vnr_tools_parse_uri_string_list_to_file_list (const gchar *uri_list)
     GSList* file_list = NULL;
     gsize i = 0;
     gchar **uris;
-    gchar* current_path;
 
     uris = g_uri_list_extract_uris (uri_list);
 
     while (uris[i] != NULL) {
-        current_path = g_file_get_path (g_file_new_for_uri(uris[i]));
+        gchar* current_path = g_file_get_path (g_file_new_for_uri(uris[i]));
         if(current_path != NULL)
             file_list = g_slist_append (file_list, current_path);
         i++;
@@ -210,4 +206,3 @@ vnr_tools_apply_embedded_orientation (GdkPixbufAnimation **anim)
 
     *anim = GDK_PIXBUF_ANIMATION(s_anim);
 }
-#endif /* __VNR_IMAGE_H__ */
