@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2015 Siyan Panayotov <contact@siyanpanayotov.com>
+ * Copyright © 2009-2018 Siyan Panayotov <contact@siyanpanayotov.com>
  *
  * This file is part of Viewnior.
  *
@@ -17,8 +17,8 @@
  * along with Viewnior.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __VNR_IMAGE_H__
-#define __VNR_IMAGE_H__
+#ifndef __VNR_TOOLS_H__
+#define __VNR_TOOLS_H__
 
 void    vnr_tools_fit_to_size (gint * w, gint * h, gint mw, gint mh);
 void    vnr_tools_fit_to_size_double (gdouble * w, gdouble * h, gint mw, gint mh);
@@ -29,4 +29,4 @@ void    vnr_tools_apply_embedded_orientation (GdkPixbufAnimation **anim);
 gint    compare_quarks (gconstpointer a, gconstpointer b);
 void    get_position_of_element_in_list(GList *list, gint *current, gint *total);
 
-#endif /* __VNR_IMAGE_H__ */
+#endif /* __VNR_TOOLS_H__ */
